#!/bin/bash

base_package_upgrade(){
	apt update
	apt dist-upgrade -y
	apt install -y git wget ca-certificates dpkg fakeroot gnupg2
}

install_package_dependency(){
	apt-get install -y --no-install-recommends ${PACKAGE_DEPENDENCY}
}

get_git_source(){
        [ -e /tmp/${APP} ] && rm -fr /tmp/${APP}
		if [ "${GIT_VERSION}" = "last" ] ;
		then
			git clone --depth 1 ${DEPOT}  /tmp/${APP}
		else
			git clone --depth 1 -b ${GIT_VERSION} ${DEPOT}  /tmp/${APP}
		fi
}

configure_depot_yarn() {
 	echo "deb [signed-by=/usr/share/keyrings/yarnkey.gpg] https://dl.yarnpkg.com/debian stable main" > /etc/apt/sources.list.d/yarn.list
 	wget -qO - https://dl.yarnpkg.com/debian/pubkey.gpg | gpg --dearmor  > /usr/share/keyrings/yarnkey.gpg
}

configure_depot_nodejs() {
        NODE_VERSION=16
        [ ! "$1" == "" ] && NODE_VERSION=$1
        XNODE_VERSION=${NODE_VERSION}.x
        grep -q ${XNODE_VERSION} /etc/apt/sources.list.d/nodesource.list
        if [ $? -ne 0 ] 
        then
                wget -qO - https://deb.nodesource.com/setup_${XNODE_VERSION} | bash
        fi
        echo -e "Package: nodejs\\nPin: version ${NODE_VERSION}.*\\nPin-Priority: 1000" > /etc/apt/preferences.d/nodejs
}

install_go() {
        GO_VERSION=1.19.2
        [ ! "$1" == "" ] && GO_VERSION=$1
        PATH=$PATH:/usr/local/go/bin
        if [ ! "$(go version)" == "go version go${GO_VERSION} linux/amd64" ] ;
        then
                rm -rvf /usr/local/go/
                wget -qO - https://go.dev/dl/go${GO_VERSION}.linux-amd64.tar.gz | tar -C /usr/local -xz
        fi
}

install_rust() {
	wget -qO - https://sh.rustup.rs > /tmp/rustup
	bash /tmp/rustup -qy
}

install_clojure() {
	wget -qO - https://download.clojure.org/install/linux-install-1.11.1.1155.sh | bash
}


minimum_package() {
	base_package_upgrade
}

default_prebuild(){
	get_git_source
}

source /tmp/src/debmaker

if [ ! "$1" == "" ];
then
	FUNC=$1
	shift
	${FUNC} $*
fi
